| Title: | Interactive Document for Working with Multidimensional Scaling and Principal Component Analysis |
|---|---|
| Description: | An interactive document on the topic of multidimensional scaling and principal component analysis using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at <https://kartikeyabolar.shinyapps.io/MDS_PCAShiny/>. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-27 08:31:06 UTC |
| Source: | https://github.com/cran/MDSPCAShiny |
MDSPCAShiny() loads interactive user interface built using R 'shiny'.
MDSPCAShiny()MDSPCAShiny()
Start MDSPCAShiny
The interactive user interface is to provide an easy way for multidimensional scaling and principal component analysis and downloading relevant plots.
Nothing
if(interactive()){ library(rmarkdown) MDSPCAShiny() }if(interactive()){ library(rmarkdown) MDSPCAShiny() }